@@ -172,7 +172,10 @@ workspace has no valid Eask-file; it will load global workspace instead."
 
 This is added because we don't want to pollute `error' and `warn' functions."
   (eask-command-p '("load" "exec" "emacs" "eval" "repl"
-                    "run/script" "run/command")))
+                    "run/script" "run/command"
+                    ;; NOTE: These test commands handle the exit code themselves;
+                    ;; therefore, we don't need to handle it for them!
+                    "test/ert" "test/ert-runner")))
 
 (defun eask-checker-p ()
   "Return t if running Eask as the checker.
@@ -286,7 +289,7 @@ The function `directory-empty-p' only exists 28.1 or above; copied it."
 
 (defun eask--guess-package-name (basename)
   "Convert the BASENAME to a valid, commonly seen package name."
-  (when-let ((name (ignore-errors (downcase basename))))
+  (when-let* ((name (ignore-errors (downcase basename))))
     (setq name (eask-s-replace "emacs-" "" name)
           name (eask-s-replace "-emacs" "" name)
           name (replace-regexp-in-string "[.-]el$" "" name))
@@ -566,8 +569,8 @@ scope of the dependencies (it's either `production' or `development')."
   (eask-defvc< 27 (eask-pkg-init))  ; XXX: remove this after we drop 26.x
   (when eask-depends-on-recipe-p
     (eask-log "Installing required external packages...")
-    (eask-with-archives '("gnu" "melpa")
-      (eask-package-install 'package-build))
+    (eask-archive-install-packages '("gnu" "melpa")
+                                   'package-build)
     (eask-with-progress
       "Building temporary archives (this may take a while)... "
       (eask-with-verbosity 'debug (github-elpa-build))
@@ -597,7 +600,7 @@ scope of the dependencies (it's either `production' or `development')."
 
 If the argument FORCE is non-nil, force initialize packages in this session."
   (when (or (not package--initialized) (not package-archive-contents) force
-            ;; XXX we need to initialize once in global scope since most Emacs
+            ;; XXX: we need to initialize once in global scope since most Emacs
             ;; configuration would likely to set `package-archives' variable
             ;; themselves.
             (and (eask-config-p) (not eask--package-initialized)))
@@ -653,6 +656,14 @@ Argument BODY are forms for execution."
          "done ✓"))
      ,@body))
 
+(defun eask-archive-install-packages (archives names)
+  "Install package NAMES with ARCHIVES setup."
+  (eask-defvc< 27 (eask-pkg-init))  ; XXX: remove this after we drop 26.x
+  (when-let* ((names (eask-listify names))
+              ((cl-some (lambda (pkg) (not (package-installed-p pkg))) names)))
+    (eask-with-archives archives
+      (eask--package-mapc #'eask-package-install names))))
+
 (defun eask-package-installable-p (pkg)
   "Return non-nil if package (PKG) is installable."
   (assq (eask-intern pkg) package-archive-contents))
@@ -686,7 +697,7 @@ Argument BODY are forms for execution."
         (eask-with-progress
           (format "  - %sInstalling %s (%s)... " eask--action-prefix name version)
           (eask-with-verbosity 'debug
-            ;; XXX Without ignore-errors guard, it will trigger error
+            ;; XXX: Without ignore-errors guard, it will trigger error
             ;;
             ;;   Can't find library xxxxxxx.el
             ;;
@@ -741,13 +752,13 @@ otherwise, we retrieve it from the variable `package-archive-contents'."
 
 For arguments NAME and CURRENT, please see function `eask-package-desc' for
 full detials."
-  (when-let ((desc (eask-package-desc name current)))
+  (when-let* ((desc (eask-package-desc name current)))
     (package-desc-version desc)))
 
 (defun eask-package--version-string (pkg)
   "Return PKG's version."
-  (if-let ((version (or (eask-package--version pkg t)
-                        (eask-package--version pkg nil))))
+  (if-let* ((version (or (eask-package--version pkg t)
+                         (eask-package--version pkg nil))))
       (package-version-join version)
     ;; Just in case, but this should never happens!
     "0"))
@@ -755,12 +766,18 @@ full detials."
 (defun eask-package-desc-url ()
   "Return url from package descriptor."
   (when eask-package-desc
-    (when-let ((extras (package-desc-extras eask-package-desc)))
+    (when-let* ((extras (package-desc-extras eask-package-desc)))
       (cdr (assoc :url extras)))))
 
 (defun eask-package-desc-keywords ()
   "Return keywords from package descriptor."
-  (when eask-package-desc (package-desc--keywords eask-package-desc)))
+  (when eask-package-desc
+    (or (package-desc--keywords eask-package-desc)
+        ;; XXX: Handle Emacs 26.x keywords cannot be parsed issue.
+        (and eask-package-file
+             (with-temp-buffer
+               (insert-file-contents eask-package-file)
+               (lm-keywords-list))))))
 
 (defun eask-pkg-el ()
   "Return package description file if exists."
@@ -775,7 +792,7 @@ full detials."
   (ignore-errors (string-to-number str)))
 
 (defun eask--flag (flag)
-  "Return non-nil if FLAG exists.."
+  "Return non-nil if FLAG exists."
   (member (concat "--eask" flag) eask-argv))
 
 (defun eask--flag-value (flag)
@@ -1129,11 +1146,11 @@ This uses function `locate-dominating-file' to look up directory tree."
   "Set up config directory in DIR, then execute BODY."
   (declare (indent 1) (debug t))
   `(let* ((user-emacs-directory (expand-file-name (concat ".eask/" emacs-version "/") ,dir))
-          (package-user-dir (expand-file-name "elpa" user-emacs-directory))
-          (early-init-file (locate-user-emacs-file "early-init.el"))
-          (eask-dot-emacs-file (locate-user-emacs-file ".emacs"))
-          (user-init-file (locate-user-emacs-file "init.el"))
-          (custom-file (locate-user-emacs-file "custom.el")))
+          (package-user-dir     (expand-file-name "elpa" user-emacs-directory))
+          (early-init-file      (locate-user-emacs-file "early-init.el"))
+          (eask-dot-emacs-file  (locate-user-emacs-file ".emacs"))
+          (user-init-file       (locate-user-emacs-file "init.el"))
+          (custom-file          (locate-user-emacs-file "custom.el")))
      ,@body))
 
 ;; NOTE: If you modified this function, make sure you modified `core/emacs.el'
@@ -1161,9 +1178,9 @@ This uses function `locate-dominating-file' to look up directory tree."
          (eask--handle-global-options)
          (cond
           ((eask-config-p)
-           (let ((early-init-file (locate-user-emacs-file "early-init.el"))
+           (let ((early-init-file     (locate-user-emacs-file "early-init.el"))
                  (eask-dot-emacs-file (locate-user-emacs-file "../.emacs"))
-                 (user-init-file (locate-user-emacs-file "init.el")))
+                 (user-init-file      (locate-user-emacs-file "init.el")))
              ;; We accept Eask-file in `config' scope, but it shouldn't be used
              ;; for the sandbox.
              (eask-with-verbosity 'debug
@@ -1387,7 +1404,7 @@ version number.  DESCRIPTION is the package description."
     (if (file-exists-p eask-package-file)
         (eask--try-construct-package-desc eask-package-file)
       (eask-warn "Package-file seems to be missing `%s'" file))
-    (when-let
+    (when-let*
         (((and (not eask-package-descriptor)  ; prevent multiple definition error
                (not eask-package-desc)))      ; check if constructed
          (pkg-file (eask-pkg-el)))
@@ -1581,7 +1598,7 @@ Execute forms BODY limit by the verbosity level (SYMBOL)."
 
 (defun eask--ansi (symbol string)
   "Paint STRING with color defined by log level (SYMBOL)."
-  (if-let ((ansi-function (cdr (assq symbol eask-level-color))))
+  (if-let* ((ansi-function (cdr (assq symbol eask-level-color))))
       (funcall ansi-function string)
     string))
 
@@ -1814,7 +1831,7 @@ Arguments FNC and ARGS are used for advice `:around'."
 
 (defun eask-package-elc-files ()
   "Return package files' elc in workspace."
-  (when-let ((elcs (mapcar (lambda (elm) (concat elm "c")) (eask-package-el-files))))
+  (when-let* ((elcs (mapcar (lambda (elm) (concat elm "c")) (eask-package-el-files))))
     (setq elcs (cl-remove-if-not (lambda (elm) (file-exists-p elm)) elcs))
     elcs))
 
