@@ -24,6 +24,11 @@
 
 (defvar check-declare-warning-buffer)
 
+;;
+;;; Flags
+
+(advice-add #'eask-allow-error-p :override #'always)
+
 ;;
 ;;; Core
 
@@ -34,10 +39,10 @@
          (errors))
     (eask-lint-first-newline)
     (eask-msg "`%s` with check-declare" (ansi-green file))
-    (setq errors (check-declare-file filename))
+    (setq errors (eask--silent (check-declare-file filename)))
     (if errors
         (with-current-buffer check-declare-warning-buffer
-          (eask-msg (buffer-string)))
+          (eask-report (string-remove-prefix "\n" (buffer-string))))
       (eask-msg "No issues found"))))
 
 (eask-start
